summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsconsolewidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsconsolewidget.h')
-rw-r--r--kjsembed/jsconsolewidget.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kjsembed/jsconsolewidget.h b/kjsembed/jsconsolewidget.h
index 52a5e0bd..0d3598ce 100644
--- a/kjsembed/jsconsolewidget.h
+++ b/kjsembed/jsconsolewidget.h
@@ -25,8 +25,8 @@
#include <tqframe.h>
#include <kjsembed/global.h>
-class TQPushButton;
-class TQHBox;
+class TTQPushButton;
+class TTQHBox;
class KLineEdit;
class KPopupTitle;
@@ -43,7 +43,7 @@ namespace KJSEmbed {
class KJSEmbedPart;
/**
* A TQWidget that provides a console for executing Javascript commands. Creating
* a JS console is easy, as you can see below:
*
* <pre>
@@ -59,12 +59,12 @@ class KJSEmbedPart;
* @version $Id$
* @author Richard Moore, rich@kde.org
*/
-class KJSEMBED_EXPORT JSConsoleWidget : public QFrame
+class KJSEMBED_EXPORT JSConsoleWidget : public TQFrame
{
Q_OBJECT
public:
- JSConsoleWidget( KJSEmbedPart *js, TQWidget *parent=0, const char *name=0 );
+ JSConsoleWidget( KJSEmbedPart *js, TTQWidget *parent=0, const char *name=0 );
virtual ~JSConsoleWidget();
public slots:
@@ -78,28 +78,28 @@ public slots:
KPopupTitle *title() const { return ttl; }
/**
* Returns the TQHBox used to layout the entry part of the console. This
* can be used by clients to hide and show the interactive parts of the
* console, or to add new buttons etc.
*/
- TQHBox *commandBox() const { return cmdBox; }
+ TTQHBox *commandBox() const { return cmdBox; }
/** Invokes the content of the command entry field. */
void invoke();
/** Invokes the specified command string. */
- virtual bool execute( const TQString &cmd );
+ virtual bool execute( const TTQString &cmd );
- bool execute( const TQString &cmd, const KJS::Value &self );
+ bool execute( const TTQString &cmd, const KJS::Value &self );
/** Prints the specified string to the console. */
- virtual void println( const TQString &text );
+ virtual void println( const TTQString &text );
/**
* Prints the specified string to the console as a warning, the default
* implementation prints the text in red.
*/
- virtual void warn( const TQString &text );
+ virtual void warn( const TTQString &text );
/**
* Runs the specified command using KShellProcess. The output of the
@@ -115,7 +115,7 @@ public slots:
* to ensure that you only expose safe objects and methods to the
* interpreter.
*/
- virtual bool run( const TQString &shellCmd );
+ virtual bool run( const TTQString &shellCmd );
protected:
/** Creates the console view. */
@@ -136,9 +136,9 @@ private:
KShellProcess *proc;
KTextEdit *log;
- TQHBox *cmdBox;
+ TTQHBox *cmdBox;
KLineEdit *cmd;
- TQPushButton *go;
+ TTQPushButton *go;
KPopupTitle *ttl;
class JSConsoleWidgetPrivate *d;
@@ -43,7 +43,7 @@ namespace KJSEmbed {
class KJSEmbedPart;
/**
- * A TQWidget that provides a console for executing Javascript commands. Creating
+ * A TTQWidget that provides a console for executing Javascript commands. Creating
* a JS console is easy, as you can see below:
*
@@ -78,28 +78,28 @@ public slots:
KPopupTitle *title() const { return ttl; }
/**
- * Returns the TQHBox used to layout the entry part of the console. This
+ * Returns the TTQHBox used to layout the entry part of the console. This
* can be used by clients to hide and show the interactive parts of the
* console, or to add new buttons etc.